pub struct ShodhBackupEngine { /* private fields */ }Expand description
Backup engine for creating and managing backups
Implementations
Sourceimpl ShodhBackupEngine
impl ShodhBackupEngine
Sourcepub fn backup_path(&self) -> &Path
pub fn backup_path(&self) -> &Path
Get the backup storage path.
Sourcepub fn create_backup(&self, db: &DB, user_id: &str) -> Result<BackupMetadata>
pub fn create_backup(&self, db: &DB, user_id: &str) -> Result<BackupMetadata>
Sourcepub fn create_comprehensive_backup(
&self,
db: &DB,
user_id: &str,
secondary_stores: &[SecondaryStoreRef<'_>],
) -> Result<BackupMetadata>
pub fn create_comprehensive_backup( &self, db: &DB, user_id: &str, secondary_stores: &[SecondaryStoreRef<'_>], ) -> Result<BackupMetadata>
Create a comprehensive backup of the main database, secondary stores, and graph.
Uses RocksDB BackupEngine for the main memories DB and Checkpoint API for secondary stores (todos, reminders, facts, files, feedback, audit) and the knowledge graph database.
Sourcepub fn create_comprehensive_backup_with_graph(
&self,
db: &DB,
user_id: &str,
secondary_stores: &[SecondaryStoreRef<'_>],
graph_db: Option<&DB>,
) -> Result<BackupMetadata>
pub fn create_comprehensive_backup_with_graph( &self, db: &DB, user_id: &str, secondary_stores: &[SecondaryStoreRef<'_>], graph_db: Option<&DB>, ) -> Result<BackupMetadata>
Create a comprehensive backup including the knowledge graph DB.
Sourcepub fn restore_backup(
&self,
user_id: &str,
backup_id: Option<u32>,
restore_path: &Path,
) -> Result<()>
pub fn restore_backup( &self, user_id: &str, backup_id: Option<u32>, restore_path: &Path, ) -> Result<()>
Restore from a specific backup
Arguments
user_id- User ID to restorebackup_id- Backup ID to restore from (None = latest)restore_path- Path to restore the database to
Sourcepub fn list_backups(&self, user_id: &str) -> Result<Vec<BackupMetadata>>
pub fn list_backups(&self, user_id: &str) -> Result<Vec<BackupMetadata>>
List all available backups for a user
Sourcepub fn restore_comprehensive_backup(
&self,
user_id: &str,
backup_id: Option<u32>,
restore_path: &Path,
secondary_restore_paths: &[(&str, &Path)],
) -> Result<Vec<String>>
pub fn restore_comprehensive_backup( &self, user_id: &str, backup_id: Option<u32>, restore_path: &Path, secondary_restore_paths: &[(&str, &Path)], ) -> Result<Vec<String>>
Restore from a comprehensive backup, including secondary stores.
The secondary_restore_paths map store names to their target restore directories.
Secondary stores are restored by copying the checkpoint directory to the target path.